src.primes package
==================

Submodules
----------

src.primes.primes module
------------------------

.. automodule:: src.primes.primes
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: src.primes
   :members:
   :undoc-members:
   :show-inheritance:
